Content

Enum Content 

pub enum Content<'de> {
Show 22 variants Bool(bool), U8(u8), U16(u16), U32(u32), U64(u64), I8(i8), I16(i16), I32(i32), I64(i64), F32(f32), F64(f64), Char(char), String(String), Str(&'de str), ByteBuf(Vec<u8>), Bytes(&'de [u8]), None, Some(Box<Content<'de>>), Unit, Newtype(Box<Content<'de>>), Seq(Vec<Content<'de>>), Map(Vec<(Content<'de>, Content<'de>)>),
}
Used from generated code to buffer the contents of the Deserializer when deserializing untagged enums and internally tagged enums.

Not public API. Use serde-value instead.

Variants



Bool(bool)



U8(u8)



U16(u16)



U32(u32)



U64(u64)



I8(i8)



I16(i16)



I32(i32)



I64(i64)



F32(f32)



F64(f64)



Char(char)



String(String)



Str(&'de str)



ByteBuf(Vec<u8>)



Bytes(&'de [u8])



None



Some(Box<Content<'de>>)



Unit



Newtype(Box<Content<'de>>)



Seq(Vec<Content<'de>>)



Map(Vec<(Content<'de>, Content<'de>)>)

Implementations

Source

impl<'de> Content<'de>

pub fn as_str(&self) -> Option<&str>