pub struct TagContentOtherFieldVisitor {
pub tag: &'static str,
pub content: &'static str,
}Expand description
Not public API.
Fields
tag: &'static strName of the tag field of the adjacently tagged enum
content: &'static strName of the content field of the adjacently tagged enum