pub struct VariantDeserializer<'de, E>where
E: Error,{ /* private fields */ }Trait Implementations
Sourceimpl<'de, E> VariantAccess<'de> for VariantDeserializer<'de, E>where
E: Error,
impl<'de, E> VariantAccess<'de> for VariantDeserializer<'de, E>where
E: Error,
Sourcetype Error = E
type Error = E
The error type that can be returned if some error occurs during
deserialization. Must match the error type of our
EnumAccess.Sourcefn unit_variant(self) -> Result<(), E>
fn unit_variant(self) -> Result<(), E>
Called when deserializing a variant with no values. Read more
Sourcefn newtype_variant_seed<T>(self, seed: T) -> Result<T::Value, E>where
T: DeserializeSeed<'de>,
fn newtype_variant_seed<T>(self, seed: T) -> Result<T::Value, E>where
T: DeserializeSeed<'de>,
Called when deserializing a variant with a single value. Read more
Sourcefn tuple_variant<V>(
self,
_len: usize,
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
fn tuple_variant<V>(
self,
_len: usize,
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
Called when deserializing a tuple-like variant. Read more
Sourcefn struct_variant<V>(
self,
_fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
fn struct_variant<V>(
self,
_fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value, Self::Error>where
V: Visitor<'de>,
Called when deserializing a struct-like variant. Read more
Sourcefn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
fn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
Called when deserializing a variant with a single value. Read more